==> jc-1.4.0.tar.gz: jas/IincOperand.h <==
// class jas.IincOperand

// class file dependencies
// @dep_class 6d0723fb21a7c58 jas_IincOperand
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_IincOperand_H_
#define _JC_jas_IincOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IincOperand$sub_refs	_jc_jas_IincOperand$sub_refs;
typedef struct _jc_jas_IincOperand$sub_nonrefs	_jc_jas_IincOperand$sub_nonrefs;
typedef struct _jc_jas_IincOperand$refs	_jc_jas_IincOperand$refs;
typedef struct _jc_jas_IincOperand$nonrefs	_jc_jas_IincOperand$nonrefs;
typedef struct _jc_jas_IincOperand$object	_jc_jas_IincOperand$object;

typedef const struct _jc_jas_IincOperand$vmethods	_jc_jas_IincOperand$vmethods;
typedef const struct _jc_jas_IincOperand$vtable	_jc_jas_IincOperand$vtable;
typedef const struct _jc_jas_IincOperand$vtype	_jc_jas_IincOperand$vtype;

// Constructors
extern void _jc_jas_IincOperand$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_jas_IincOperand$object *, jint, jint);

// Virtual methods
extern void _jc_jas_IincOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_IincOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_IincOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
extern void _jc_jas_IincOperand$method$writePrefix$829d20cc218d44c9(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_IincOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_IincOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_IincOperand$method_info$write$d61e8c36d8c1cacd;
extern _jc_method _jc_jas_IincOperand$method_info$writePrefix$829d20cc218d44c9;

// Virtual methods structure
struct _jc_jas_IincOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
	void	(*writePrefix$829d20cc218d44c9)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_IincOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_IincOperand$vmethods	jas_IincOperand;
};

// Vtype
struct _jc_jas_IincOperand$vtype {
	_jc_type			type;
	_jc_jas_IincOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IincOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IincOperand$refs {
    _jc_jas_IincOperand$sub_refs	jas_IincOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IincOperand$sub_nonrefs {
	jint	vindex;
	jint	constt;
};

// Non-reference instance fields (object)
struct _jc_jas_IincOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_IincOperand$sub_nonrefs	jas_IincOperand;
};

// Object instance structure
struct _jc_jas_IincOperand$object {
	_jc_jas_IincOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IincOperand$vtype	*vtype;
	_jc_jas_IincOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IincOperand$vtype _jc_jas_IincOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IincOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IincOperand$class_object;

#endif	/* _JC_jas_IincOperand_H_ */

==> jc-1.4.6.tar.gz: jas/IincOperand.h <==
// class jas.IincOperand

// class file dependencies
// @dep_class 6d0723fb21a7c58 jas_IincOperand
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_IincOperand_H_
#define _JC_jas_IincOperand_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IincOperand$sub_refs	_jc_jas_IincOperand$sub_refs;
typedef struct _jc_jas_IincOperand$sub_nonrefs	_jc_jas_IincOperand$sub_nonrefs;
typedef struct _jc_jas_IincOperand$refs	_jc_jas_IincOperand$refs;
typedef struct _jc_jas_IincOperand$nonrefs	_jc_jas_IincOperand$nonrefs;
typedef struct _jc_jas_IincOperand$object	_jc_jas_IincOperand$object;

typedef const struct _jc_jas_IincOperand$vmethods	_jc_jas_IincOperand$vmethods;
typedef const struct _jc_jas_IincOperand$vtable	_jc_jas_IincOperand$vtable;
typedef const struct _jc_jas_IincOperand$vtype	_jc_jas_IincOperand$vtype;

// Constructors
extern void _jc_jas_IincOperand$method$_init$02b806c1c13eed5e(_jc_env *, struct _jc_jas_IincOperand$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_IincOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_IincOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_IincOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
extern void _jc_jas_IincOperand$method$writePrefix$829d20cc218d44c9(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_IincOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_IincOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_IincOperand$method_info$write$d61e8c36d8c1cacd;
extern _jc_method _jc_jas_IincOperand$method_info$writePrefix$829d20cc218d44c9;

// Virtual methods structure
struct _jc_jas_IincOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
	void	(*writePrefix$829d20cc218d44c9)(_jc_env *, struct _jc_jas_IincOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_IincOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_IincOperand$vmethods	jas_IincOperand;
};

// Vtype
struct _jc_jas_IincOperand$vtype {
	_jc_type			type;
	_jc_jas_IincOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IincOperand$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IincOperand$refs {
    _jc_jas_IincOperand$sub_refs	jas_IincOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IincOperand$sub_nonrefs {
	jint	vindex;
	jint	constt;
};

// Non-reference instance fields (object)
struct _jc_jas_IincOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_IincOperand$sub_nonrefs	jas_IincOperand;
};

// Object instance structure
struct _jc_jas_IincOperand$object {
	_jc_jas_IincOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IincOperand$vtype	*vtype;
	_jc_jas_IincOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IincOperand$vtype _jc_jas_IincOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IincOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IincOperand$class_object;

#endif	/* _JC_jas_IincOperand_H_ */
